@@ -26,15 +26,18 @@ Checks for termination after if population has converged
 
 package Algorithm::Evolutionary::Op::Convergence_Terminator;
 
-our ($VERSION) = ( '$Revision: 1.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
 =head2 new( [$population_proportion = 0.5] )
 
 Creates a new generational terminator:
+
   my $ct = new Algorithm::Evolutionary::Op::Convergence_Terminator 0.5; 
-will make the C<apply> method return false after if 50% of the population are the same 
+
+will make the C<apply> method return false after if 50% of the
+population are the same, that is, its "genetic" representation is equal.
 
 =cut
 
@@ -84,10 +87,10 @@ L<Algorithm::Evolutionary::Op::DeltaTerm>.
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/04/03 16:00:49 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Convergence_Terminator.pm,v 1.2 2009/04/03 16:00:49 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/28 11:30:56 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Convergence_Terminator.pm,v 3.1 2009/07/28 11:30:56 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.2 $
+  $Revision: 3.1 $
   $Name $
 
 =cut
