@@ -46,9 +46,9 @@ package Algorithm::Evolutionary::Op::Crossover;
 
 use lib qw(../../..);
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
 
-use Clone::Fast qw(clone);
+use Clone qw(clone);
 use Carp;
 
 use base 'Algorithm::Evolutionary::Op::Base';
@@ -90,11 +90,8 @@ parents at the same time, check L<QuadXOver|Algorithm::Evolutionary::Op::QuadXOv
 sub  apply ($$$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-#  my $victim = $arg->clone();
   my $victim = clone( $arg );
   my $victim2 = shift || croak "No victim here!";
-#  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
-#  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
   my $pt1 = int( rand( $minlen ) );
@@ -120,6 +117,8 @@ sub  apply ($$$){
 
 =item L<Algorithm::Evolutionary::Op::Gene_Boundary_Crossover> don't disturb the building blocks!
 
+=item L<Algorithm::Evolutionary::Op::Uniform_Crossover_Diff> vive la difference!
+
 =back
 
 =head1 Copyright
@@ -127,10 +126,10 @@ sub  apply ($$$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/03/16 18:39:40 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 3.1 2010/03/16 18:39:40 jmerelo Exp $ 
+  CVS Info: $Date: 2011/02/14 06:55:36 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 3.2 2011/02/14 06:55:36 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 3.2 $
   $Name $
 
 =cut
